<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Form_EditComment
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Form_EditComment extends Moc10_Form
{

    /**
     * Form templates
     * @var array
     */
    protected $_templates = array('main' => null, 'mobile' => null);

    /**
     * $_POST fields
     * @var array
     */
    protected $_postFields = array('plugin' => null,
                                   'comment_content' => null,
                                   'comment_approved' => null,
                                   'comment_is_spam' => null,
                                   'mobile' => null,
                                   'comment_id' => 0);

    /**
     * Initialization method for the edit comment form.
     *
     * @param  array $post
     * @return void
     */
    public function init($post = null)
    {

        $lang = new Phire_Language();

        $this->_setFields($post);
        $this->_setTemplates();

        $this->setAttributes('id', 'editCommentForm');

        // Create the 'comment_content' form element.
        $comment_content = new Moc10_Form_Element_Textarea('comment_content', $this->_postFields['comment_content']);
        $comment_content->setLabel($lang->__('Comment:'));
        $comment_content->setAttributes('cols', ((!is_null($this->_postFields['mobile'])) ? '30' : '125'));
        $comment_content->setAttributes('rows', ((!is_null($this->_postFields['mobile'])) ? '5' : '10'));
        $comment_content->setAttributes('spellcheck', 'false');
        $comment_content->setRequired(true);

        // Create the 'comment_id' form element.
        $comment_id = new Moc10_Form_Element('hidden', 'comment_id', $this->_postFields['comment_id']);

        // Create the 'submit' form element.
        $submit = new Moc10_Form_Element('submit', 'submit', $lang->__('SAVE'));
        $submit->setAttributes('style', 'float: right;');

        // Set whether it's a mobile form template or not.
        if (!is_null($this->_postFields['mobile'])) {
        $submit->setAttributes('class', 'submitBtn');
            $this->setTemplate($this->_templates['mobile']);
        } else {
            $submit->setAttributes('class', 'submitBtn');
            $this->setAttributes('onsubmit', "return editCommentFrm.validate();");
            $comment_content->setAttributes('style', 'width: 640px;');
            $this->setTemplate($this->_templates['main']);
        }

        // Add the form element objects to the form.
        $this->addElements(array($comment_content, $submit, $comment_id));

    }

    /**
     * Method to save the comment data.
     *
     * @return void
     */
    public function saveData()
    {

        if ($this->_postFields['comment_id'] != 0) {

            $comment = new Phire_Table_Comments();
            $comment->findById($this->_postFields['comment_id']);

            $comment->comment_content = $this->_postFields['comment_content'];
            $comment->comment_approved = (($this->_postFields['comment_approved'] == 'Yes') ? $this->_postFields['comment_approved'] : 'No');
            $comment->comment_is_spam = (($this->_postFields['comment_is_spam'] == 'Yes') ? $this->_postFields['comment_is_spam'] : 'No');

            $comment->save();

        }


    }

    /**
     * Method to set the post fields.
     *
     * @param  array $post
     * @return void
     */
    protected function _setFields($post = null)
    {

        if (!is_null($post)) {
            if ((!$_POST) && isset($post['comment_id']) && ($post['comment_id'] != 0)) {

                $comment = new Phire_Table_Comments();
                $comment->findById($post['comment_id']);

                $this->_postFields['comment_content'] = (string)Moc10_String::setString($comment->comment_content)->strip()->html();
                $this->_postFields['comment_approved'] = (string)Moc10_String::setString($comment->comment_approved)->strip()->html();
                $this->_postFields['comment_is_spam'] = (string)Moc10_String::setString($comment->comment_is_spam)->strip()->html();
                $this->_postFields['plugin'] = (isset($post['plugin'])) ? $post['plugin'] : null;
                $this->_postFields['mobile'] = (isset($post['mobile'])) ? $post['mobile'] : null;
                $this->_postFields['comment_id'] = $comment->comment_id;

            } else {
                foreach ($post as $key => $value) {
                    if (array_key_exists($key, $this->_postFields)) {
                        $this->_postFields[$key] = (isset($post[$key])) ? $post[$key] : null;
                    }
                }
            }
        }

    }

    /**
     * Method to set the form templates.
     *
     * @return void
     */
    protected function _setTemplates()
    {

        $lang = new Phire_Language();

        $cmt = new Phire_Table_Comments();
        $cmt->execute("SELECT * FROM " . DB_PREFIX . "comments LEFT JOIN " . DB_PREFIX . "pages ON " . DB_PREFIX . "comments.page_id = " . DB_PREFIX . "pages.page_id LEFT JOIN " . DB_PREFIX . "sites ON " . DB_PREFIX . "pages.site_id = " . DB_PREFIX . "sites.site_id WHERE comment_id = '" . (string)Moc10_String::setString($this->_postFields['comment_id'])->escape(true)->striptags() . "'");

        $app_chk = ($this->_postFields['comment_approved'] == 'Yes') ? "checked=\"checked\" " : '';
        $spam_chk = ($this->_postFields['comment_is_spam'] == 'Yes') ? "checked=\"checked\" " : '';

        $cmtPage = $cmt->site_domain . BASE_PATH . $cmt->page_url;
        $cmtPosted = (string)Moc10_String::setString($cmt->comment_posted)->date('l, M j, Y g:i A');

        if (!is_null($this->_postFields['plugin'])) {
            $plugin = "<input type=\"hidden\" name=\"plugin\" value=\"{$this->_postFields['plugin']}\" />";
            $plg_lnk = BASE_PATH . CONTENT_PATH . "/extensions/plugins/{$this->_postFields['plugin']}/?sys_path=" . BASE_PATH . SYS_PATH;
            $plg_cancel = "&plugin={$this->_postFields['plugin']}";
        } else {
            $plugin = null;
            $plg_lnk = './comments.php';
            $plg_cancel = null;
        }

        $back = $lang->__('Back');
        $blue = $lang->__('Blue fields are required.');
        $ste_pg = $lang->__('Site/Page:');
        $auth = $lang->__('Author:');
        $from = $lang->__('Posted From:');
        $posted = $lang->__('Posted:');
        $mark = $lang->__('Mark as Spam?');
        $app = $lang->__('Approve Comment?');
        $cancel = $lang->__('CANCEL');

        // Define the main form template.
        $this->_templates['main'] = <<<FORMTEMP
            <table id="headerTable" cellpadding="0" cellspacing="0"><tr><td>&lt;&lt;&lt; <a class="orangeLink" href="{$plg_lnk}">{$back}</a></td></tr></table>
            <table id="dataAltTable" cellspacing="0" cellpadding="0">
                <tr class="grayHeader">
                    <td class="grayHeader">
                        &nbsp;
                    </td>
                </tr>
                <tr>
                    <td style="padding: 15px;">
                        <table id="entryTable" cellspacing="0" cellpadding="0">
                            <tr>
                                <td>
                                    &nbsp;
                                </td>
                                <td>
                                    <h4>{$blue}</h4>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    {$ste_pg}
                                </td>
                                <td>
                                    <a class="smallLink" style="font-size: 1.0em;" href="http://{$cmtPage}" target="_blank">{$cmtPage}</a>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    {$auth}
                                </td>
                                <td>
                                    {$cmt->comment_author}
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    {$from}
                                </td>
                                <td>
                                    {$cmt->comment_ip}
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    {$posted}
                                </td>
                                <td>
                                    {$cmtPosted}
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight" style="vertical-align: top;">
                                    [{comment_content_label}]
                                </td>
                                <td>
                                    [{comment_content}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    &nbsp;
                                </td>
                                <td class="textRight">
                                    <span style="float: right;"><input style="float: right; margin: 0 0 0 8px; padding: 0;" type="checkbox" class="checkBox" name="comment_is_spam" id="comment_is_spam" value="Yes" {$spam_chk}/>{$mark}</span>
                                    <span style="clear: right;"><br /></span>
                                    <span style="clear: right; float: right;"><input style="float: right; margin: 0 0 0 8px; padding: 0;" type="checkbox" class="checkBox" name="comment_approved" id="comment_approved" value="Yes" {$app_chk}/>{$app}</span>
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    <a style="margin: 0 0 0 10px; padding-top: 6px; height: 19px; font-size: 0.825em; float: right;" class="submitGrayBtn" href="../core/process/edit.comment.php?action=cancel{$plg_cancel}">{$cancel}</a> [{submit}] [{comment_id}] {$plugin}
                                </td>
                            </tr>
                        </table>
                        <script type="text/javascript">
                            editCommentFormInit();
                        </script>
                    </td>
                </tr>
            </table>
FORMTEMP;

        $mobile = (!is_null($this->_postFields['mobile'])) ? "<input type=\"hidden\" name=\"mobile\" value=\"true\" />" : null;

        // Define the mobile form template.
        $this->_templates['mobile'] = <<<FORMTEMP
            <table id="headerTable" cellpadding="0" cellspacing="0"><tr><td>&lt;&lt;&lt; <a class="orangeLink" href="./comments.php">{$back}</a></td></tr></table>
            <table id="dataAltTable" cellspacing="0" cellpadding="0">
                <tr class="grayHeader" style="height; 16px;">
                    <td class="grayHeader" style="height; 16px;">
                        &nbsp;
                    </td>
                </tr>
                <tr>
                    <td style="padding: 5px;">
                        <table id="entryTable" cellspacing="0" cellpadding="0">
                            <tr>
                                <td>
                                    &nbsp;
                                </td>
                                <td>
                                    <h4>{$blue}</h4>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    {$ste_pg}
                                </td>
                                <td>
                                    <a class="smallLink" style="font-size: 1.0em;" href="http://{$cmtPage}" target="_blank">{$cmtPage}</a>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    {$auth}
                                </td>
                                <td>
                                    {$cmt->comment_author}
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    {$from}
                                </td>
                                <td>
                                    {$cmt->comment_ip}
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    {$posted}
                                </td>
                                <td>
                                    {$cmtPosted}
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight" style="vertical-align: top;">
                                    [{comment_content_label}]
                                </td>
                                <td>
                                    [{comment_content}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    &nbsp;
                                </td>
                                <td class="textRight">
                                    <span style="float: right;"><input style="float: right; margin: 0 0 0 8px; padding: 0;" type="checkbox" class="checkBox" name="comment_is_spam" id="comment_is_spam" value="Yes" {$spam_chk}/>{$mark}</span>
                                    <span style="clear: right; float: right;"><input style="float: right; margin: 0 0 0 8px; padding: 0;" type="checkbox" class="checkBox" name="comment_approved" id="comment_approved" value="Yes" {$app_chk}/>{$app}</span>
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    <a style="float: right; margin: 0 0 0 5px; padding: 2px 3px 4px 3px; height: 10px; font-size: 0.9em;" class="submitBtnGray" href="../../core/process/edit.comment.php?action=cancel&mobile=true">{$cancel}</a> [{submit}] [{comment_id}] {$mobile}
                                </td>
                            </tr>
                        </table>
                    </td>
                </tr>
            </table>
FORMTEMP;

    }

}
